from distutils.core import setup

#python setup.py sdist upload -r pypi
setup(name='effigy',
      version='0.3.9',
      description='Framework for creating visual node-based coding',
      url='https://github.com/DrLuke/effigy',
      author='DrLuke',
      author_email='Lukas+pypi@Jackowski.de',
      license='MIT',
      packages=['effigy'])
